package com.kob.backend.service.impl.user.account;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.kob.backend.pojo.User;
import com.kob.backend.mapper.UserMapper;
import com.kob.backend.service.user.account.RegisterService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.Map;
import java.util.List;

@Service
public class RegisterServiceImpl implements RegisterService {
    //    这里使用 @Autowired 注入是为了调用数据库,然后进行数据库查询,比较是否有用户名重复
    @Autowired
    private UserMapper userMapper;

    @Override
    public Map<String, String> register(String username, String password, String confirmedPassword) {
        Map<String, String> map = new HashMap<>();
//        如果用户名为空,则提示用户返回
        if (username == null) {
            map.put("error_message", "用户名不能为空");
            return map;
        }
        if (password == null || confirmedPassword == null) {
            map.put("error_message", "密码不能为空");
            return map;
        }
//        用户名需要将输入的首尾空格删掉
        username = username.trim();
        if (username.length() == 0) {
            map.put("error_message", "用户名不能为空");
            return map;
        }
        if (password.length() == 0) {
            map.put("error_message", "密码不能为空");
            return map;
        }
        if (username.length() > 100) {
            map.put("error_message", "用户名过长");
            return map;
        }



/*
        查询数据库里是否有用户名 this.username 已存在的用户,并将结果存入 users 中,
        如果发现 users 不是空的,则告诉注册用户当前用户名已存在
*/
        QueryWrapper<User> queryWrapper = new QueryWrapper<User>();
        queryWrapper.eq("username", username);
        List<User> users = userMapper.selectList(queryWrapper);
        if (!users.isEmpty()) {
            map.put("error_message", "用户名已存在");
            return map;
        }
        // 密码验证是 String 类型比较,应该用 equals() 方法
        else if (!confirmedPassword.equals(password)) {
            map.put("error_message", "两次密码输入不一致");
            return map;
        } else if (password.length() < 2) {
            map.put("error_message", "密码不能少于2位");
            return map;
        } else if (password.length() > 100) {
            map.put("error_message", "密码过长");
            return map;
        }

//        异常情况判断结束,开始将合法用户注册信息注入数据库
//        对密码进行加密
        String encodedPassword = new BCryptPasswordEncoder().encode(password);
//        默认头像
        String photo = "https://cdn.acwing.com/media/user/profile/photo/253652_lg_e3d8435b66.jpg";
//        id 是数据库自增,这里生成新用户只需要将 id 参数写为 null 即可
        User user = new User(null, username, encodedPassword, photo);
        userMapper.insert(user);

        map.put("error_message", "successRegister");
        return map;
    }
}
