package com.kob.backend.service.impl.user.bot;

import com.kob.backend.mapper.BotMapper;
import com.kob.backend.pojo.Bot;
import com.kob.backend.pojo.User;
import com.kob.backend.service.impl.utils.UserDetailsImpl;
import com.kob.backend.service.user.bot.RemoveService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.Map;

@Service
public class RemoveServiceImpl implements RemoveService {
    @Autowired
    private BotMapper botMapper;

    @Override
    public Map<String, String> remove(Map<String, String> data) {
//        先取出当前用户信息
        UsernamePasswordAuthenticationToken authenticationToken =
                (UsernamePasswordAuthenticationToken) SecurityContextHolder.getContext().getAuthentication();
        UserDetailsImpl loginUser = (UserDetailsImpl) authenticationToken.getPrincipal();
        User user = loginUser.getUser();

//        从用户输入参数判断要删除的 bot id
        int bot_id = Integer.parseInt(data.get("bot_id"));
        Bot bot = botMapper.selectById(bot_id);

//        定义返回值
        Map<String, String> map = new HashMap<>();

//        如果 bot 不存在
        if (bot == null) {
            map.put("error_message", "Bot 不存在或已被删除");
            return map;
        }

//        如果 bot 的 user_id 不等于 User 的 id
        if (!bot.getUserId().equals(user.getId())) {
            map.put("error_message", "你无权删除别人的 bot");
            return map;
        }

//        判断成功后进行删除
        botMapper.deleteById(bot_id);
        map.put("error_message", "success");
        return map;
    }
}
